==> jc-1.4.0.tar.gz: java__5fcup/runtime/virtual__5fparse__5fstack.h <==
// public class java_cup.runtime.virtual_parse_stack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a1c125f6173f27 java__5fcup_runtime_virtual__5fparse__5fstack

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_
#define _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Stack$object;

// Typedefs
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$object;

typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods;
typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable;
typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype;

// Constructors
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$_init$dd1f9cec36ac68f6(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, struct _jc_java_util_Stack$object *);

// Virtual methods
extern jboolean _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$empty$a66e7e55a0392358(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$get__5ffrom__5freal$57fcabca09ef53cf(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$pop$73381a92c26c579b(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$push$ee254462186acba7(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, jint);
extern jint _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$top$b1c24048bf74ea8c(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$empty$a66e7e55a0392358;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$get__5ffrom__5freal$57fcabca09ef53cf;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$pop$73381a92c26c579b;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$push$ee254462186acba7;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$top$b1c24048bf74ea8c;

// Virtual methods structure
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods {
	jboolean	(*empty$a66e7e55a0392358)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
	void	(*get__5ffrom__5freal$57fcabca09ef53cf)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
	void	(*pop$73381a92c26c579b)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
	void	(*push$ee254462186acba7)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, jint);
	jint	(*top$b1c24048bf74ea8c)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *);
};

// Vtable
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods	java__5fcup_runtime_virtual__5fparse__5fstack;
};

// Vtype
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype {
	_jc_type			type;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs {
	struct _jc_java_util_Stack$object	*real__5fstack;
	struct _jc_java_util_Stack$object	*vstack;
};

// Reference instance fields (object)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs {
    _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs	java__5fcup_runtime_virtual__5fparse__5fstack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs {
	jint	real__5fnext;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs	java__5fcup_runtime_virtual__5fparse__5fstack;
};

// Object instance structure
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object {
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype	*vtype;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype _jc_java__5fcup_runtime_virtual__5fparse__5fstack$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_runtime_virtual__5fparse__5fstack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_runtime_virtual__5fparse__5fstack$class_object;

#endif	/* _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/runtime/virtual__5fparse__5fstack.h <==
// public class java_cup.runtime.virtual_parse_stack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a3a1c125f6173f27 java__5fcup_runtime_virtual__5fparse__5fstack

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_
#define _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Stack$object;

// Typedefs
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs;
typedef struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$object;

typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods;
typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable;
typedef const struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype;

// Constructors
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$_init$dd1f9cec36ac68f6(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$empty$a66e7e55a0392358(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$get__5ffrom__5freal$57fcabca09ef53cf(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$pop$73381a92c26c579b(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$push$ee254462186acba7(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method$top$b1c24048bf74ea8c(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$empty$a66e7e55a0392358;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$get__5ffrom__5freal$57fcabca09ef53cf;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$pop$73381a92c26c579b;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$push$ee254462186acba7;
extern _jc_method _jc_java__5fcup_runtime_virtual__5fparse__5fstack$method_info$top$b1c24048bf74ea8c;

// Virtual methods structure
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods {
	jboolean	(*empty$a66e7e55a0392358)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
	void	(*get__5ffrom__5freal$57fcabca09ef53cf)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
	void	(*pop$73381a92c26c579b)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
	void	(*push$ee254462186acba7)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *, jint) _JC_JCNI_ATTR;
	jint	(*top$b1c24048bf74ea8c)(_jc_env *, struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vmethods	java__5fcup_runtime_virtual__5fparse__5fstack;
};

// Vtype
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype {
	_jc_type			type;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs {
	struct _jc_java_util_Stack$object	*real__5fstack;
	struct _jc_java_util_Stack$object	*vstack;
};

// Reference instance fields (object)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs {
    _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_refs	java__5fcup_runtime_virtual__5fparse__5fstack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs {
	jint	real__5fnext;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_runtime_virtual__5fparse__5fstack$sub_nonrefs	java__5fcup_runtime_virtual__5fparse__5fstack;
};

// Object instance structure
struct _jc_java__5fcup_runtime_virtual__5fparse__5fstack$object {
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype	*vtype;
	_jc_java__5fcup_runtime_virtual__5fparse__5fstack$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_runtime_virtual__5fparse__5fstack$vtype _jc_java__5fcup_runtime_virtual__5fparse__5fstack$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_runtime_virtual__5fparse__5fstack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_runtime_virtual__5fparse__5fstack$class_object;

#endif	/* _JC_java__5fcup_runtime_virtual__5fparse__5fstack_H_ */
